==> haskell-word-wrap-0.4.1-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 word-wrap
version:              0.4.1
visibility:           public
id:                   word-wrap-0.4.1-8NY3o2y31kgJY4HFceQSSf
key:                  word-wrap-0.4.1-8NY3o2y31kgJY4HFceQSSf
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  cd5552a506ad49f0dc54f5f88388d935
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-8.8.3/site-local/word-wrap-0.4.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/word-wrap-0.4.1
hs-libraries:         HSword-wrap-0.4.1-8NY3o2y31kgJY4HFceQSSf
depends:              base-4.13.0.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-word-wrap-0.4.1-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 word-wrap
version:              0.4.1
visibility:           public
id:                   word-wrap-0.4.1-8VonUWL81EFK4KtfESpGXQ
key:                  word-wrap-0.4.1-8VonUWL81EFK4KtfESpGXQ
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  1705747ae9d8290438130b0bbff10ac8
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-8.8.3/site-local/word-wrap-0.4.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/word-wrap-0.4.1
hs-libraries:         HSword-wrap-0.4.1-8VonUWL81EFK4KtfESpGXQ
depends:              base-4.13.0.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
